==> plesk-billing-6.0.3.tar.gz: plesk-billing-6.0.3/plesk-billing/order/include/lib-action/shopping/ShowMultiDomainWhois.php <==
<?php
// +----------------------------------------------------------------------+
// | ModernBill [TM] .:. Client Billing System                            |
// +----------------------------------------------------------------------+
// | Copyright (c) 2001-2005 ModernGigabyte, LLC                          |
// +----------------------------------------------------------------------+
// | This source file is subject to the ModernBill End User License       |
// | Agreement (EULA), that is bundled with this package in the file      |
// | LICENSE, and is available at through the world-wide-web at           |
// | http://www.modernbill.com/extranet/LICENSE.txt                       |
// | If you did not receive a copy of the ModernBill license and are      |
// | unable to obtain it through the world-wide-web, please send a note   |
// | to license@modernbill.com so we can email you a copy immediately.    |
// +----------------------------------------------------------------------+
// | Authors: ModernGigabyte, LLC <info@moderngigabyte.com>               |
// | Support: http://www.modernsupport.com/modernbill/                    |
// +----------------------------------------------------------------------+
// | ModernGigabyte and ModernBill are trademarks of ModernGigabyte, LLC. |
// +----------------------------------------------------------------------+


if(!$CONF || $_REQUEST["CONF"]) {
	if (!defined("MB_LIBPATH")){
		define("MB_LIBPATH", realpath(dirname(__FILE__)."/../../../.."));
		require_once(MB_LIBPATH."/lib-pkg/parsefunction.php");
	}
	require_once mb_path("/lib-tk/include/common.php");
}
require_once mb_path("/lib-action/action.php");

/**
 * @author  Kris Bailey
 */
class ShowMultiDomainWhois extends MB_Action {
	function ShowMultiDomainWhois(){
		parent::MB_Action();
		$this->stringRep = "ShowMultiDomainWhois";

		$this->params = array();
		$this->sortColumns = array();
	}

	/**
	 * The main method of this class that executes the AddCartDomain action, and returns success or failure.
	 *
	 * @return  1 if this action executed successfully, or 0 if otherwise.
	 */
	function execute() {
		global $CONF;
		parent::execute();

		$CONF["theme"]["type"] = "public";

		dbg("show multi domain whois");

		$this->smartyVars = array();

		if ($CONF["secureURLProtocol"]=="http"){
			$this->smartyVars["cartURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/cart.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["transferURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/remote.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["whoisURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/remotewhois.php?multiDomain=1&sid=".$_REQUEST["sid"];
			$url = new URL($this->smartyVars["whoisURL"]);
			$this->smartyVars["baseURL"] = $CONF["secureURLProtocol"]."://".$url->getHost();
		} else {
			$this->smartyVars["cartURL"] = $CONF["secureURLProtocol"]."://".$CONF["secureURL"].mb_path_convert_path("/order")."/cart.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["transferURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/remote.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["whoisURL"] = $CONF["secureURLProtocol"]."://".$CONF["secureURL"].mb_path_convert_path("/order")."/remotewhois.php?multiDomain=1&sid=".$_REQUEST["sid"];
			$url = new URL($this->smartyVars["whoisURL"]);
			$this->smartyVars["baseURL"] = $CONF["secureURLProtocol"]."://".$url->getHost();
		}
		if ($_REQUEST["wwid"]){
			$wwXML = "	<mbapi>
					<command>GetWebsiteWidgets</command>
					<params>
						<websiteWidgetID>".((int)$_REQUEST["wwid"])."</websiteWidgetID>
						<getProductInformation>1</getProductInformation>
						<getOrderFormData>1</getOrderFormData>
					</params>
					</mbapi>";
			$wwInfo = dispatchMBAPI($wwXML, 1);
			dbg("website widget info we got back:");
			dbg($wwInfo);

			dbg("at the top of website widget show action. 4");

			$wwInfo = grabSimpleMBAPIResults($wwInfo);
			$wwInfo = $wwInfo[0];
			$orderFormID = $this->smartyVars["orderFormID"] = $wwInfo["orderFormID"];
		} elseif ($_REQUEST["orderFormID"]){
			$orderFormID = $this->smartyVars["orderFormID"] = $_REQUEST["orderFormID"];
		}
		
		$orderFormData = oneByID(":orderForms", $orderFormID);
		$paymentGroupData = oneByID(":paymentGroups", $orderFormData["paymentGroupID"]);
		$this->smartyVars["currencyID"] = $currencyID = $paymentGroupData["paymentGroupCurrencyID"];
		
		$shoppingSessionData = $this->updateShoppingSession($_REQUEST["sid"], $orderFormID);

		
		$domains = getMBAPIArray("GetShoppingItemsDomains", array(
			"shoppingSessionID" => $_REQUEST["sid"],
		));
		$this->smartyVars["domainsInCart"] = array();
		foreach ($domains as $d){
			$this->smartyVars["domainsInCart"][$d["domainSLD"].".".$d["domainTLD"]] = 1;
		}
//		$this->smartyVars["domainsInCart"] = array_keys($this->smartyVars["domainsInCart"]);
		
		
		if ($_REQUEST["domainSLD"]){
			$this->smartyVars["domainSLD"] = str_replace(array("http://", "https://", "www."), "", strtolower($_REQUEST["domainSLD"]));
			if (strpos($this->smartyVars["domainSLD"], ".")!==false){
				$this->smartyVars["domainSLD"] = substr($this->smartyVars["domainSLD"], 0, strpos($this->smartyVars["domainSLD"], "."));
			}
			$this->smartyVars["selectedTLD"] = $_REQUEST["domainTLD"];
		}
		
		$domainProducts = arrayFor("products", array(
			"getProductVariantData" => 1,
			"productType" => getAPITypeID("products", "domain"),
			"productActive" => 1,
		));
		$keyedProducts = array();
		foreach ((array)$domainProducts as $product){
			$keyedProducts[$product["productID"]] = $product;
		}
		$productIDs = array_keys($keyedProducts);
		
		dbg($keyedProducts);
		
		$orderFormItems = arrayFor(":orderFormItems", array(
			"orderFormID" => $orderFormID,
			"productID" => $productIDs,
		));
		
		dbg($orderFormItems);
		
		if (!count($orderFormItems)){
			$this->smartyVars["noDomainProductFound"] = 1;
		} else {
			$this->smartyVars["productID"] = $domainProductID = $orderFormItems[0]["productID"];
			$domainProduct =& $keyedProducts[$domainProductID];

			if (!$domainProduct){
				$this->smartyVars["noDomainProductFound"] = 1;
			} else {
				$tldIDs = array();

				$variants = $domainProduct["productVariants"];
				$tldPrices = array();
				$tldHasTransferPrice = array();
				$variants2tlds = array();
				foreach ((array)$variants as $v){
					if ($v["productVariantActive"]){
						$tldIDs[] = $v["tldID"];
						$variants2tlds[$v["productVariantID"]] = $v["tldID"];
					}
				}

				$tlds2variants = array_flip($variants2tlds);

				$domainProductPrices = oneByID("products", $domainProduct["productID"], array(
					"getProductVariantPriceData" => 1,
				));

				$variantPrices = $domainProductPrices["productVariantPrices"];
				foreach ((array)$variantPrices as $price){
					if ($price["currencyID"]==$currencyID && $price["productVariantPriceAmount"]>0){
						$tldPrices[$variants2tlds[$price["productVariantID"]]][$price["cycleID"]][$price["productVariantPriceType"]] = $CONF["user"]["locale"]->getLocaleCurrency($price["productVariantPriceAmount"], $currencyID);
						if ($price["productVariantPriceType"]==getAPITypeID("price", "transfer")){
							$tldHasTransferPrice[$variants2tlds[$price["productVariantID"]]] = true;
						}
					}
				}

				$tlds = arrayFor(":TLDs", array(
					"sortColumn" => "tldDisplayOrder",
					"sortDir" => "ASC",
					"tldActive" => 1,
					"tldID" => $tldIDs,
				));
				$this->smartyVars["cycleInfo"] = getCyclesArray();
				$this->smartyVars["cycleValues"] = array();
				foreach ($this->smartyVars["cycleInfo"] as $cycleID=>$cycleName){
					$this->smartyVars["cycleValues"][$cycleID] = getNextBillingTimestamp(0, $cycleID);
				}
				$this->smartyVars["tlds"] = array();
				foreach ($tlds as $tld){
					$tld["productID"] = $domainProductID;
					$tld["productVariantID"] = $tlds2variants[$tld["tldID"]];
					$tld["prices"] = $tldPrices[$tld["tldID"]];
					$tld["hasTransferPrice"] = $tldHasTransferPrice[$tld["tldID"]];
					$this->smartyVars["tlds"][$tld["tldExtension"]] = $tld;
				}
			}
			
		}
			
		$this->smartyVars["showDomainBox"] = (!$_REQUEST["domainSLD"]) ? 1 : 0;
		if ($_REQUEST["preCart"]){
			$this->addTemplate("shopping/ShowMultiDomainWhoisStep", $this->smartyVars);
		} else {
			$this->addTemplate("shopping/ShowMultiDomainWhois", $this->smartyVars);
		}
		
		$this->addErrorTemplates();
		return $this->hasExecutedSuccessfully();
	}

} // ShowMultiDomainWhois

==> plesk-billing-6.0.4.tar.gz: plesk-billing-6.0.4/plesk-billing/order/include/lib-action/shopping/ShowMultiDomainWhois.php <==
<?php

if(!$CONF || $_REQUEST["CONF"]) {
	if (!defined("MB_LIBPATH")){
		define("MB_LIBPATH", realpath(dirname(__FILE__)."/../../../.."));
		require_once(MB_LIBPATH."/lib-pkg/parsefunction.php");
	}
	require_once mb_path("/lib-tk/include/common.php");
}
require_once mb_path("/lib-action/action.php");

/**
 * @author  Kris Bailey
 */
class ShowMultiDomainWhois extends MB_Action {
	/**
	 * The main method of this class that executes the AddCartDomain action, and returns success or failure.
	 *
	 * @return  1 if this action executed successfully, or 0 if otherwise.
	 */
	function execute() {
		global $CONF;
		parent::execute();

		$CONF["theme"]["type"] = "public";

		dbg("show multi domain whois");

		$this->smartyVars = array();

		if ($CONF["secureURLProtocol"]=="http"){
			$this->smartyVars["cartURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/cart.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["transferURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/remote.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["whoisURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/remotewhois.php?multiDomain=1&sid=".$_REQUEST["sid"];
		} else {
			$this->smartyVars["cartURL"] = $CONF["secureURLProtocol"]."://".$CONF["secureURL"].mb_path_convert_path("/order")."/cart.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["transferURL"] = $CONF["secureURLProtocol"]."://".$CONF["standardURL"].mb_path_convert_path("/order")."/remote.php?sid=".$_REQUEST["sid"];
			$this->smartyVars["whoisURL"] = $CONF["secureURLProtocol"]."://".$CONF["secureURL"].mb_path_convert_path("/order")."/remotewhois.php?multiDomain=1&sid=".$_REQUEST["sid"];
		}

		$url = parse_url($this->smartyVars["whoisURL"]);
		$this->smartyVars["baseURL"] = $CONF["secureURLProtocol"]."://".$url["host"];

		if ($_REQUEST["wwid"]){
			$wwXML = "	<mbapi>
					<command>GetWebsiteWidgets</command>
					<params>
						<websiteWidgetID>".((int)$_REQUEST["wwid"])."</websiteWidgetID>
						<getProductInformation>1</getProductInformation>
						<getOrderFormData>1</getOrderFormData>
					</params>
					</mbapi>";
			$wwInfo = dispatchMBAPI($wwXML, 1);
			dbg("website widget info we got back:");
			dbg($wwInfo);

			dbg("at the top of website widget show action. 4");

			$wwInfo = grabSimpleMBAPIResults($wwInfo);
			$wwInfo = $wwInfo[0];
			$orderFormID = $this->smartyVars["orderFormID"] = $wwInfo["orderFormID"];
		} elseif ($_REQUEST["orderFormID"]){
			$orderFormID = $this->smartyVars["orderFormID"] = $_REQUEST["orderFormID"];
		}
		
		$orderFormData = oneByID(":orderForms", $orderFormID);
		$paymentGroupData = oneByID(":paymentGroups", $orderFormData["paymentGroupID"]);
		$this->smartyVars["currencyID"] = $currencyID = $paymentGroupData["paymentGroupCurrencyID"];
		
		$shoppingSessionData = $this->updateShoppingSession($_REQUEST["sid"], $orderFormID);

		
		$domains = getMBAPIArray("GetShoppingItemsDomains", array(
			"shoppingSessionID" => $_REQUEST["sid"],
		));
		$this->smartyVars["domainsInCart"] = array();
		foreach ($domains as $d){
			$this->smartyVars["domainsInCart"][$d["domainSLD"].".".$d["domainTLD"]] = 1;
		}
//		$this->smartyVars["domainsInCart"] = array_keys($this->smartyVars["domainsInCart"]);
		
		
		if ($_REQUEST["domainSLD"]){
			$this->smartyVars["domainSLD"] = str_replace(array("http://", "https://", "www."), "", strtolower($_REQUEST["domainSLD"]));
			if (strpos($this->smartyVars["domainSLD"], ".")!==false){
				$this->smartyVars["domainSLD"] = substr($this->smartyVars["domainSLD"], 0, strpos($this->smartyVars["domainSLD"], "."));
			}
			$this->smartyVars["selectedTLD"] = $_REQUEST["domainTLD"];
		}
		
		$domainProducts = arrayFor("products", array(
			"getProductVariantData" => 1,
			"productType" => getAPITypeID("products", "domain"),
			"productActive" => 1,
		));
		$keyedProducts = array();
		foreach ((array)$domainProducts as $product){
			$keyedProducts[$product["productID"]] = $product;
		}
		$productIDs = array_keys($keyedProducts);
		
		dbg($keyedProducts);
		
		$orderFormItems = arrayFor(":orderFormItems", array(
			"orderFormID" => $orderFormID,
			"productID" => $productIDs,
		));
		
		dbg($orderFormItems);
		
		if (!count($orderFormItems)){
			$this->smartyVars["noDomainProductFound"] = 1;
		} else {
			$this->smartyVars["productID"] = $domainProductID = $orderFormItems[0]["productID"];
			$domainProduct =& $keyedProducts[$domainProductID];

			if (!$domainProduct){
				$this->smartyVars["noDomainProductFound"] = 1;
			} else {
				$tldIDs = array();

				$variants = $domainProduct["productVariants"];
				$tldPrices = array();
				$tldHasTransferPrice = array();
				$variants2tlds = array();
				foreach ((array)$variants as $v){
					if ($v["productVariantActive"]){
						$tldIDs[] = $v["tldID"];
						$variants2tlds[$v["productVariantID"]] = $v["tldID"];
					}
				}

				$tlds2variants = array_flip($variants2tlds);

				$domainProductPrices = oneByID("products", $domainProduct["productID"], array(
					"getProductVariantPriceData" => 1,
				));

				$variantPrices = $domainProductPrices["productVariantPrices"];
				foreach ((array)$variantPrices as $price){
					if ($price["currencyID"]==$currencyID && $price["productVariantPriceAmount"]>0){
						$tldPrices[$variants2tlds[$price["productVariantID"]]][$price["cycleID"]][$price["productVariantPriceType"]] = $CONF["user"]["locale"]->getLocaleCurrency($price["productVariantPriceAmount"], $currencyID);
						if ($price["productVariantPriceType"]==getAPITypeID("price", "transfer")){
							$tldHasTransferPrice[$variants2tlds[$price["productVariantID"]]] = true;
						}
					}
				}

				$tlds = arrayFor(":TLDs", array(
					"sortColumn" => "tldDisplayOrder",
					"sortDir" => "ASC",
					"tldActive" => 1,
					"tldID" => $tldIDs,
				));
				$this->smartyVars["cycleInfo"] = getCyclesArray();
				$this->smartyVars["cycleValues"] = array();
				foreach ($this->smartyVars["cycleInfo"] as $cycleID=>$cycleName){
					$this->smartyVars["cycleValues"][$cycleID] = getNextBillingTimestamp(0, $cycleID);
				}
				$this->smartyVars["tlds"] = array();
				foreach ($tlds as $tld){
					$tld["productID"] = $domainProductID;
					$tld["productVariantID"] = $tlds2variants[$tld["tldID"]];
					$tld["prices"] = $tldPrices[$tld["tldID"]];
					$tld["hasTransferPrice"] = $tldHasTransferPrice[$tld["tldID"]];
					$this->smartyVars["tlds"][$tld["tldExtension"]] = $tld;
				}
			}
			
		}
			
		$this->smartyVars["showDomainBox"] = (!$_REQUEST["domainSLD"]) ? 1 : 0;
		if ($_REQUEST["preCart"]){
			$this->addTemplate("shopping/ShowMultiDomainWhoisStep", $this->smartyVars);
		} else {
			$this->addTemplate("shopping/ShowMultiDomainWhois", $this->smartyVars);
		}
		
		$this->addErrorTemplates();
		return $this->hasExecutedSuccessfully();
	}

} // ShowMultiDomainWhois
